@@ -343,7 +343,7 @@ nco_ppc_set_var /* Set PPC flag and value for all variables to be bitmasked/roun
 
 void
 nco_ppc_around /* [fnc] Replace op1 values by their values rounded to decimal precision prc */
-(const int ppc, /* I [nbr] Precision-preserving compression, i.e., number of total or decimal significant digits */
+(const int ppc, /* I [nbr] Precision-preserving compression, i.e., number of sig. digits/bits */
  const nc_type type, /* I [enm] netCDF type of operand */
  const long sz, /* I [nbr] Size (in elements) of operand */
  const int has_mss_val, /* I [flg] Flag for missing values */
@@ -541,7 +541,9 @@ nco_ppc_around /* [fnc] Replace op1 values by their values rounded to decimal pr
 
 void
 nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
-(const int nsd, /* I [nbr] Number of significant digits, i.e., arithmetic precision */
+(const int nc_out_id, /* I [id] Output netCDF file ID */
+ const int var_out_id, /* I [id] Variable ID in output file */
+ const int nsd, /* I [nbr] Number of significant digits, i.e., arithmetic precision */
  const nc_type type, /* I [enm] netCDF type of operand */
  const long sz, /* I [nbr] Size (in elements) of operand */
  const int has_mss_val, /* I [flg] Flag for missing values */
@@ -551,8 +553,9 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   /* Threads: Routine is thread safe and calls no unsafe routines */
 
   /* Purpose: Implement NCO NSD PPC algorithm (BitGroom) from Zen16 by masking-out insignificant bits of op1 values
-     Also performs all other bitmasking algorithms, including BitRound, Granular BitGroom, BitSet, BitShave, ... */
-  
+     Also performs all other bitmasking algorithms, including BitRound, Granular BitGroom, BitSet, BitShave, ... 
+     As of 20240408 (total solar eclipse day!), also calls nco_qnt_mtd() to write CF-compliant lossy metadata */
+
   /* Bitmask is currently defined as op1:=bitmask(op1,ppc) */  
   
   /* This routine implements the BitGrooming Number of Significant Digits (NSD) algorithm
@@ -937,7 +940,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       /* !DigitRound = DGR */
     case nco_baa_gbr:
       /* Granular BitGroom
-	 Test GBG:
+	 Test GBR:
 	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
 	 ncks -O -7 -C -D 1 --baa=4 -v ppc_btg --ppc default=3 ~/nco/data/in.nc ~/foo.nc
 	 ncks -O -7 -C -D 1 --baa=4 -v one_dmn_rec_var_flt --ppc default=3 ~/nco/data/in.nc ~/foo.nc */
@@ -949,7 +952,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 	  //mnt_log10_prx=mnt_log10_tbl_gbr[tbl_idx][1];
 	  //dgt_nbr=(int)floor(xpn_bs2*dgt_per_bit+mnt_log10_prx)+1; /* DGG19 p. 4102 (9) */
 #if 1
-	  /* Default GBG path */
+	  /* Default GBR path */
 	  mnt_fabs=fabs(mnt);
 	  mnt_log10_fabs=log10(mnt_fabs);
 	  /* 20211003 Continuous determination of dgt_nbr improves CR by ~10% */
@@ -990,7 +993,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 	} /* !mss_val_cmp_flt */
       } /* !idx */
       break;
-      /* !GranularBitRound = GBG */
+      /* !GranularBitRound = GBR */
     case nco_baa_bgr:
     case nco_baa_btr:
       /* BitRound and
@@ -1261,7 +1264,35 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     nco_dfl_case_nc_type_err();
     break;
   } /* !type */
-  
+
+  /* 20240408 Write CF-compliant metadata for all variables that were lossily transformed
+     This switch() is a bit redundant since function has already returned for non-floating-point types 
+     And for float point types with invalid quantization levels, for that matter 
+     Thus if this following switch() is reached at all, then losssy metadata should be written
+     This is the only place where the output variable IDs are used
+     To keep things simple, we pass nsd to the nco_qnt_mtd() routine
+     Whether GTT nsd refers to either NSD or NSB depends on the algorithm
+     Careful readers and nco_qnt_mtd() know how to determine that */
+  switch(type){
+  case NC_FLOAT: 
+  case NC_DOUBLE: 
+    (void)nco_qnt_mtd(nc_out_id,var_out_id,(nco_flt_typ_enm)nco_baa_cnv_typ,(nco_flt_typ_enm)0,nsd);
+  break;
+  case NC_INT: /* Do nothing for non-floating point types ...*/
+  case NC_SHORT:
+  case NC_CHAR:
+  case NC_BYTE:
+  case NC_UBYTE:
+  case NC_USHORT:
+  case NC_UINT:
+  case NC_INT64:
+  case NC_UINT64:
+  case NC_STRING: break;
+  default: 
+    nco_dfl_case_nc_type_err();
+    break;
+  } /* !type */
+
   /* 20150126: fxm casting pointers is tricky with this routine. Avoid for now. */
   /* NB: it is not neccessary to un-typecast pointers to values after access 
      because we have only operated on local copies of them. */
